@@ -1,7 +1,7 @@
 package Code::Embeddable;
 
 our $DATE = '2015-06-18'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,49 +65,6 @@ sub uniq (@) {
 }
 # END_BLOCK: uniq
 
-if (0) { <<'_' }
-# BEGIN_BLOCK: stacktrace_printer
-my %OLD_SIG;
-BEGIN {
-    @OLD_SIG{qw/__DIE__ __WARN__/} = @SIG{qw/__DIE__ __WARN__/};
-    my $longmess = sub {
-        my $mess = '';
-        my $i = 2;
-        {
-            package DB;
-            while (my @caller = caller($i)) {
-                if ($i == 2) { $mess .= $_[0] }
-                $mess .= "\t";
-                if ($caller[3]) { # subroutine
-                    $mess .= "$caller[3](";
-                    if ($caller[4]) { # has_args
-                        my $j = 0;
-                        for my $arg0 (@DB::args) {
-                            my $arg = $arg0; # copy
-                            if ($j++) { $mess .= ", " }
-                            if (!defined($arg)) { $arg = "undef" }
-                            elsif (ref($arg)) { }
-                            else { $arg =~ s/([\\'])/\\$1/g; $arg = "'$arg'" }
-                            $mess .= $arg;
-                        }
-                    }
-                    $mess .= ") called ";
-                }
-                $mess .= "at $caller[1] line $caller[2]\n";
-                $i++;
-            }
-        }
-        $mess;
-    };
-    $SIG{__DIE__}  = sub { die &$longmess };
-    $SIG{__WARN__} = sub { warn &$longmess };
-}
-END {
-    @SIG{qw/__DIE__ __WARN__/} = @OLD_SIG{qw/__DIE__ __WARN__/};
-}
-# END_BLOCK: stacktrace_printer
-_
-
 1;
 # ABSTRACT: Collection of routines that can be embedded e.g. using Dist::Zilla plugin
 
@@ -123,7 +80,7 @@ Code::Embeddable - Collection of routines that can be embedded e.g. using Dist::
 
 =head1 VERSION
 
-This document describes version 0.04 of Code::Embeddable (from Perl distribution Code-Embeddable), released on 2015-06-18.
+This document describes version 0.05 of Code::Embeddable (from Perl distribution Code-Embeddable), released on 2015-06-18.
 
 =head1 SYNOPSIS
 
@@ -179,15 +136,6 @@ don't have to load the module.
 
 These embeddable pieces of code are not function declaration:
 
-=head2 stacktrace_printer
-
-A very simple and lightweight stacktrace printer which does not require any
-module like L<Carp::Always> or L<Devel::Confess>. This will make every warn() or
-die() print a stack trace. Does not support fancy stuffs that the other
-stacktrace printer does, e.g. dumping of complex function arguments, colors,
-etc. It just shows each level's filename/line number/function name with argument
-list.
-
 =head1 SEE ALSO
 
 L<Dist::Zilla::Plugin::InsertBlock::FromModule>
